@@ -1,8 +1,6 @@
 import ConfigParser
 import os
 
-import log
-
 _cached_config = None
 
 def load_config(configfile=None):
@@ -16,17 +14,15 @@ def load_config(configfile=None):
    # try:
    #     config.readfp(open(os.path.join(os.path.dirname(__file__),
    #                                         "..", "data", "defaults")))
-   #     log.debug("Loaded default configuration")
    # except IOError:
-   #     log.error("Unable to load default configuraiton. The program"
-   #             " may not work correctly.")
+   #     print "Unable to load default configuraiton. The program"
+   #             " may not work correctly."
 
     # Now load the system/user specific config (if any)
     if configfile:
-        loaded = config.read([configfile])
+        config.read([configfile])
     else:
-        loaded = config.read(['/etc/circonusapirc',
+        config.read(['/etc/circonusapirc',
                                 os.path.expanduser('~/.circonusapirc')])
-    log.debug("Loaded config files: %s" % ', '.join(loaded))
     _cached_config = config
     return config
